ledger.DebtsByPartner (Debts) — amici1

# `ledger.DebtsByPartner` (Debts)

Columns

- `lino.core.actors.Actor.detail_link`

- `lino_xl.lib.ledger.ui.ExpectedMovements.info`

- `lino_xl.lib.ledger.ui.ExpectedMovements.match`

- `lino_xl.lib.ledger.ui.ExpectedMovements.due_date`

- `lino_xl.lib.ledger.ui.ExpectedMovements.debts`

- `lino_xl.lib.ledger.ui.ExpectedMovements.payments`

- `lino_xl.lib.ledger.ui.ExpectedMovements.balance`

- `lino_xl.lib.ledger.ui.ExpectedMovements.partner`

- `lino_xl.lib.ledger.ui.ExpectedMovements.account`

- `lino_xl.lib.ledger.ui.ExpectedMovements.bank_account`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

Filter parameters

- `<django.db.models.fields.DateField: date_until>`

- `<lino.core.choicelists.ChoiceListField: trade_type>`

- `<django.db.models.fields.related.ForeignKey: from_journal>`

- `<django.db.models.fields.related.ForeignKey: for_journal>`

- `<django.db.models.fields.related.ForeignKey: account>`

- `<django.db.models.fields.related.ForeignKey: partner>`

- `<lino.core.fields.DummyField object at 0x7fc81dffecc0>`

- `<lino.core.choicelists.ChoiceListField: show_sepa>`

- `<lino.core.choicelists.ChoiceListField: same_dc>`

## Filter parameters